@@ -1,9 +1,9 @@
-from PyObjCTools.TestSupport import *
-
-from ImageCaptureCore import *
+import ImageCaptureCore
+from PyObjCTools.TestSupport import TestCase
+import objc
 
 
-class TestICDeviceBrowserHelper(NSObject):
+class TestICDeviceBrowserHelper(ImageCaptureCore.NSObject):
     def deviceBrowser_didAddDevice_moreComing_(self, b, d, m):
         pass
 
@@ -23,8 +23,4 @@ class TestICDeviceBrowser(TestCase):
             TestICDeviceBrowserHelper.deviceBrowser_didRemoveDevice_moreGoing_, 2
         )
 
-        self.assertResultIsBOOL(ICDeviceBrowser.isBrowsing)
-
-
-if __name__ == "__main__":
-    main()
+        self.assertResultIsBOOL(ImageCaptureCore.ICDeviceBrowser.isBrowsing)
